##  Explore Authentication and Authorization Options
SAP LeanIX offers several options for managing authentication and authorization.
  * Authentication is the process of verifying the identity of a user or system attempting to access SAP LeanIX. You can manage authentication in SAP LeanIX or through single sign-on (SSO).


  * Authorization determines what actions an authenticated user is allowed to perform in SAP LeanIX. You manage authorization by assigning user roles and defining permissions, either in SAP LeanIX or through SSO.


Choose how you want to manage authentication and authorization for your organization. For detailed information, see [Authentication and Authorization](https://help.sap.com/docs/leanix/ea/managing-users?locale=en-US&state=PRODUCTION&version=CLOUD#loio275afeb47a441014b2a8c3973c072ba7__section_oxb_jvx_1hc).
